@@ -34,9 +34,13 @@ class FileList:
 		elif isinstance(flist, str):
 			flist = [flist]
 
-		s = set(self.__list)
-		s.update(flist)
-		self.__list = list(s)
+		for f in flist:
+			if f in self.__list:
+				continue
+			
+			self.__list.append(f)
+		
+		
 		
 		return self.__list
 			
